@@ -1,9 +1,9 @@
 /*  Zutils - Utilities dealing with compressed files
-    Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014 Antonio Diaz Diaz.
+    Copyright (C) 2009-2014 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
+    the Free Software Foundation, either version 2 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -122,8 +122,8 @@ bool parse_rc_line( const std::string & line,
       return false; }
   const std::string name( line, l, i - l );
   int format_index = -1;
-  for( int i = 0; i < num_formats; ++i )
-    if( name == format_names[i] ) { format_index = i; break; }
+  for( int j = 0; j < num_formats; ++j )
+    if( name == format_names[j] ) { format_index = j; break; }
   if( format_index < 0 )
     { if( verbosity >= 0 )
         std::fprintf( stderr, "%s %d: bad format name '%s'\n",
@@ -170,7 +170,7 @@ int process_rcfile( const std::string & name )
   while( true )
     {
     const std::string & line = my_fgets( f, linenum );
-    if( line.size() == 0 ) break;	// EOF
+    if( line.empty() ) break;				// EOF
     if( !parse_rc_line( line, name.c_str(), linenum ) )
       { retval = 2; break; }
     }
@@ -226,7 +226,9 @@ void parse_compressor( const std::string & arg, const int format_index,
 
 const char * get_compressor_name( const int format_index )
   {
-  if( format_index >= 0 && format_index < num_formats )
+  if( format_index >= 0 && format_index < num_formats &&
+      compressor_names[format_index].size() &&
+      compressor_names[format_index][0] != '-' )
     return compressor_names[format_index].c_str();
   return 0;
   }
@@ -245,11 +247,11 @@ void show_help_addr()
   }
 
 
-void show_version( const char * const Program_name )
+void show_version()
   {
-  std::printf( "%s (zutils) %s\n", Program_name, PROGVERSION );
+  std::printf( "%s (zutils) %s\n", program_name, PROGVERSION );
   std::printf( "Copyright (C) %s Antonio Diaz Diaz.\n", program_year );
-  std::printf( "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n"
+  std::printf( "License GPLv2+: GNU GPL version 2 or later <http://gnu.org/licenses/gpl.html>\n"
                "This is free software: you are free to change and redistribute it.\n"
                "There is NO WARRANTY, to the extent permitted by law.\n" );
   }
@@ -263,7 +265,7 @@ void show_error( const char * const msg, const int errcode, const bool help )
       {
       std::fprintf( stderr, "%s: %s", program_name, msg );
       if( errcode > 0 )
-        std::fprintf( stderr, ": %s", std::strerror( errcode ) );
+        std::fprintf( stderr, ": %s.", std::strerror( errcode ) );
       std::fprintf( stderr, "\n" );
       }
     if( help )
@@ -284,7 +286,7 @@ void show_error2( const char * const msg, const char * const name )
 void internal_error( const char * const msg )
   {
   if( verbosity >= 0 )
-    std::fprintf( stderr, "%s: internal error: %s.\n", program_name, msg );
+    std::fprintf( stderr, "%s: internal error: %s\n", program_name, msg );
   std::exit( 3 );
   }
 
